/**
 * Cookie Away - Global Privacy Control (GPC) Implementation
 * 
 * This content script implements GPC support for websites by:
 * 1. Adding a meta tag to the document head
 * 2. Setting the navigator.globalPrivacyControl property
 */

(function() {
  // Check if GPC is enabled in the extension settings
  chrome.storage.local.get(['preferences'], function(data) {
    const preferences = data.preferences || {};
    const gpcEnabled = preferences.enableGPC === true;
    
    if (gpcEnabled) {
      console.log('Cookie Away: Implementing GPC on this page');
      
      // Method 1: Add meta tag to the page
      const metaTag = document.createElement('meta');
      metaTag.name = 'globalPrivacyControl';
      metaTag.content = '1';
      document.head.appendChild(metaTag);
      
      // Method 2: Set navigator property (using Object.defineProperty for compatibility)
      try {
        if (!('globalPrivacyControl' in navigator)) {
          Object.defineProperty(navigator, 'globalPrivacyControl', {
            value: true,
            writable: false,
            configurable: false
          });
        }
      } catch (error) {
        console.error('Cookie Away: Error setting navigator.globalPrivacyControl:', error);
      }
    }
  });
})();