/**
 * Cookie Information handler for Cookie Away
 */

function detectCookieInformation() {
  try {
    // Look for Cookie Information specific elements
    return (
      document.getElementById('coiOverlay') ||
      document.getElementById('coiConsentBanner') ||
      document.querySelector('[data-coi-consent-banner]') ||
      document.querySelector('.coi-banner__wrapper') ||
      document.querySelector('[class*="CookieInformation"]') ||
      typeof window.CookieInformation !== 'undefined' ||
      typeof window.CookieConsent !== 'undefined' && document.querySelector('.cookie-consent-banner')
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Cookie Information - ${error.message}`);
    return false;
  }
}

function handleCookieInformation(preferences) {
  try {
    // Get the CookieInformation banner
    const banner = document.getElementById('coiConsentBanner') || 
                  document.querySelector('.coi-banner__wrapper') ||
                  document.querySelector('[data-coi-consent-banner]');
    
    if (!banner) {
      console.log('Cookie Away: Cookie Information banner not found');
      notifyBackgroundScript('Cookie Information', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(banner, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'accept & close'
      ]);
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(banner, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies'
      ]);
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(banner, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings'
      ]);
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find checkboxes or switches for each category
          const settingsPanel = document.querySelector('.coi-consent-banner__category-expander') ||
                              document.querySelector('.coi-banner__page--preferences');
          
          if (settingsPanel) {
            // Find the category containers
            const categoryContainers = settingsPanel.querySelectorAll('.coi-consent-banner__category');
            
            // Loop through categories and set preferences
            categoryContainers.forEach(container => {
              const categoryLabel = container.querySelector('.coi-consent-banner__category-name').textContent.toLowerCase();
              const toggle = container.querySelector('input[type="checkbox"]');
              
              // Skip if necessary/required cookies (usually can't be disabled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || categoryLabel.includes('essential')) {
                return;
              }
              
              // Set toggle according to preferences
              if (toggle) {
                if (
                  (categoryLabel.includes('analytic') && preferences.analytics) ||
                  (categoryLabel.includes('functional') && preferences.functional) ||
                  (categoryLabel.includes('preference') && preferences.functional) ||
                  (categoryLabel.includes('advertis') && preferences.advertising) ||
                  (categoryLabel.includes('market') && preferences.advertising)
                ) {
                  if (!toggle.checked) toggle.click();
                } else {
                  if (toggle.checked) toggle.click();
                }
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(settingsPanel, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings'
            ]);
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Cookie Information', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Cookie Information', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Cookie Information - ${error.message}`);
    notifyBackgroundScript('Cookie Information', false);
  }
}