/**
 * CookieYes handler for Cookie Away
 */

function detectCookieYes() {
  try {
    // Look for CookieYes specific elements
    return (
      document.getElementById('cookie-law-info-bar') ||
      document.getElementById('cookie-law-info-again') ||
      document.querySelector('.cli-modal') ||
      document.querySelector('[data-cli_action]') ||
      document.querySelector('[class*="cookieyes"]') ||
      document.querySelector('[id*="cookieyes"]') ||
      typeof window.cookieyes !== 'undefined' ||
      typeof window.wt_cli_settings !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting CookieYes - ${error.message}`);
    return false;
  }
}

function handleCookieYes(preferences) {
  try {
    // Get the CookieYes banner
    const banner = document.getElementById('cookie-law-info-bar') || 
                  document.querySelector('.wt-cli-cookie-bar') ||
                  document.querySelector('.cookieyes-banner');
    
    if (!banner) {
      console.log('Cookie Away: CookieYes banner not found');
      notifyBackgroundScript('CookieYes', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(banner, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || banner.querySelector('.cli_action_button[data-cli_action="accept"]') ||
          banner.querySelector('.cookieyes-accept-btn');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(banner, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || banner.querySelector('.cli_action_button[data-cli_action="reject"]') ||
          banner.querySelector('.cookieyes-reject-btn');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(banner, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'preferences', 'manage consent', 'show details'
      ]) || banner.querySelector('.cli_settings_button') ||
          banner.querySelector('.cookieyes-settings-btn');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings modal to appear
        setTimeout(() => {
          // Try to find the settings modal
          const settingsModal = document.querySelector('.cli-modal-dialog') ||
                              document.querySelector('.cky-consent-container') ||
                              document.querySelector('.cky-preference-center-modal');
          
          if (settingsModal) {
            // Find the category toggles
            const toggles = settingsModal.querySelectorAll('input[type="checkbox"]');
            
            // Loop through toggles and set preferences
            toggles.forEach(toggle => {
              if (toggle.disabled) return;
              
              const categoryLabel = toggle.closest('.cli-tab-section, .cky-category-item')
                ? toggle.closest('.cli-tab-section, .cky-category-item').textContent.toLowerCase()
                : toggle.parentElement.textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || 
                  categoryLabel.includes('essential') || categoryLabel.includes('functional')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('performance') && preferences.analytics) ||
                (categoryLabel.includes('statistic') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('experience') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising) ||
                (categoryLabel.includes('target') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(settingsModal, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit',
              'save & accept', 'save and accept', 'save changes'
            ]) || settingsModal.querySelector('.cli_setting_save_button') ||
               settingsModal.querySelector('.cky-btn-preferences');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('CookieYes', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('CookieYes', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling CookieYes - ${error.message}`);
    notifyBackgroundScript('CookieYes', false);
  }
}