/**
 * Crownpeak (Evidon) handler for Cookie Away
 */

function detectCrownpeak() {
  try {
    // Look for Crownpeak/Evidon specific elements
    return (
      document.getElementById('_evidon_banner') ||
      document.getElementById('_evidon-banner') ||
      document.getElementById('evidon-banner') ||
      document.getElementById('evidon-prefdiag') ||
      document.querySelector('.evidon-banner') ||
      document.querySelector('[id^="evidon"]') ||
      typeof window.evidon !== 'undefined' ||
      typeof window._bcapi !== 'undefined' ||
      typeof window._bcq !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Crownpeak/Evidon - ${error.message}`);
    return false;
  }
}

function handleCrownpeak(preferences) {
  try {
    // Get the Crownpeak/Evidon banner
    const banner = document.getElementById('_evidon_banner') || 
                  document.getElementById('evidon-banner') ||
                  document.querySelector('.evidon-banner');
    
    if (!banner) {
      console.log('Cookie Away: Crownpeak/Evidon banner not found');
      notifyBackgroundScript('Crownpeak', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(banner, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'accept', 'agree'
      ]);
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(banner, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'decline', 'reject'
      ]);
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(banner, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings', 'more info',
        'manage cookies', 'cookie preferences'
      ]);
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the preference dialog
          const settingsPanel = document.getElementById('evidon-prefdiag') ||
                              document.querySelector('#evidon-prefdiag-wrapper');
          
          if (settingsPanel) {
            // Find the category toggles
            const categoryToggles = settingsPanel.querySelectorAll('input[type="checkbox"]');
            
            // Loop through toggles and set preferences
            categoryToggles.forEach(toggle => {
              const categoryLabel = toggle.closest('div, tr, li').textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be disabled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || categoryLabel.includes('essential')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('statistic') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(settingsPanel, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit'
            ]);
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Crownpeak', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Crownpeak', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Crownpeak/Evidon - ${error.message}`);
    notifyBackgroundScript('Crownpeak', false);
  }
}