/**
 * Didomi handler for Cookie Away
 */

function detectDidomi() {
  try {
    // Look for Didomi specific elements
    return (
      document.getElementById('didomi-notice') ||
      document.querySelector('.didomi-notice') ||
      document.querySelector('[id^="didomi-"]') ||
      document.querySelector('[class^="didomi-"]') ||
      typeof window.Didomi !== 'undefined' ||
      typeof window.didomiState !== 'undefined' ||
      typeof window.didomiEventListeners !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Didomi - ${error.message}`);
    return false;
  }
}

function handleDidomi(preferences) {
  try {
    // Get the Didomi notice
    const notice = document.getElementById('didomi-notice') || 
                  document.querySelector('.didomi-notice') ||
                  document.querySelector('[id^="didomi-notice"]');
    
    if (!notice) {
      console.log('Cookie Away: Didomi notice not found');
      notifyBackgroundScript('Didomi', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(notice, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || notice.querySelector('#didomi-notice-agree-button');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(notice, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject', 'disagree', 'refuse'
      ]) || notice.querySelector('#didomi-notice-disagree-button');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(notice, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'more options', 'personalise'
      ]) || notice.querySelector('#didomi-notice-learn-more-button');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the preferences panel
          const preferencesPanel = document.querySelector('#didomi-preferences') ||
                                document.querySelector('.didomi-preferences-popup');
          
          if (preferencesPanel) {
            // Handle the purposes/categories tab
            const purposesTab = preferencesPanel.querySelector('[data-didomi-panel="purposes"]') ||
                              preferencesPanel.querySelector('.didomi-preferences-purposes');
            
            if (purposesTab) {
              // Ensure the purposes tab is active
              const purposesTabButton = preferencesPanel.querySelector('[data-didomi-target="purposes"]');
              if (purposesTabButton) {
                safeClick(purposesTabButton);
              }
              
              // Wait for the tab to become active
              setTimeout(() => {
                // Find all toggles
                const toggles = purposesTab.querySelectorAll('input[type="checkbox"]');
                
                // Loop through toggles and set preferences
                toggles.forEach(toggle => {
                  if (toggle.disabled) return;
                  
                  const categoryLabel = toggle.closest('.didomi-consent-popup-category, .didomi-consent-popup-purpose')
                    .textContent.toLowerCase();
                  
                  // Skip if necessary/required cookies (usually can't be toggled)
                  if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || 
                      categoryLabel.includes('essential') || categoryLabel.includes('legitimate')) {
                    return;
                  }
                  
                  // Set toggle according to preferences
                  if (
                    (categoryLabel.includes('analytic') && preferences.analytics) ||
                    (categoryLabel.includes('statistic') && preferences.analytics) ||
                    (categoryLabel.includes('measure') && preferences.analytics) ||
                    (categoryLabel.includes('functional') && preferences.functional) ||
                    (categoryLabel.includes('preference') && preferences.functional) ||
                    (categoryLabel.includes('experience') && preferences.functional) ||
                    (categoryLabel.includes('advertis') && preferences.advertising) ||
                    (categoryLabel.includes('market') && preferences.advertising) ||
                    (categoryLabel.includes('target') && preferences.advertising) ||
                    (categoryLabel.includes('social') && preferences.advertising)
                  ) {
                    if (!toggle.checked) toggle.click();
                  } else {
                    if (toggle.checked) toggle.click();
                  }
                });
                
                // Find and click the save/confirm button
                const saveButton = findButtonByText(preferencesPanel, [
                  'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit',
                  'save and close', 'save & close', 'confirm my choices'
                ]) || preferencesPanel.querySelector('#didomi-preferences-save-button');
                
                if (saveButton) {
                  safeClick(saveButton);
                  notifyBackgroundScript('Didomi', true);
                }
              }, 300);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Didomi', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Didomi - ${error.message}`);
    notifyBackgroundScript('Didomi', false);
  }
}