/**
 * Finsweet Cookie Consent handler for Cookie Away
 */

function detectFinsweet() {
  try {
    // Look for Finsweet specific elements
    return (
      document.querySelector('.fs-cc-banner') ||
      document.querySelector('[fs-cc-banner]') ||
      document.querySelector('[data-fs-cc-banner]') ||
      document.querySelector('[class*="fs-cc-"]') ||
      document.querySelector('[class*="finsweet-cookie"]') ||
      typeof window.fsAttributes !== 'undefined' && window.fsAttributes.length && window.fsAttributes.includes('cc')
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Finsweet - ${error.message}`);
    return false;
  }
}

function handleFinsweet(preferences) {
  try {
    // Get the Finsweet banner
    const banner = document.querySelector('.fs-cc-banner') || 
                  document.querySelector('[fs-cc-banner]') ||
                  document.querySelector('[data-fs-cc-banner]');
    
    if (!banner) {
      console.log('Cookie Away: Finsweet banner not found');
      notifyBackgroundScript('Finsweet', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(banner, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || banner.querySelector('[fs-cc-button="accept"]') || banner.querySelector('[data-fs-cc-button="accept"]');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(banner, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || banner.querySelector('[fs-cc-button="decline"]') || banner.querySelector('[data-fs-cc-button="decline"]');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(banner, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'preference center', 'more info'
      ]) || banner.querySelector('[fs-cc-button="preferences"]') || banner.querySelector('[data-fs-cc-button="preferences"]');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the preferences panel
          const preferencesPanel = document.querySelector('.fs-cc-prefs_component') ||
                                 document.querySelector('[fs-cc-prefs]') ||
                                 document.querySelector('[data-fs-cc-prefs]');
          
          if (preferencesPanel) {
            // Find the category toggles
            const toggles = preferencesPanel.querySelectorAll('input[type="checkbox"]');
            
            // Loop through toggles and set preferences
            toggles.forEach(toggle => {
              if (toggle.disabled) return;
              
              const categoryLabel = toggle.closest('[fs-cc-checkbox], [data-fs-cc-checkbox]')
                ? toggle.closest('[fs-cc-checkbox], [data-fs-cc-checkbox]').textContent.toLowerCase()
                : toggle.parentElement.textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || 
                  categoryLabel.includes('essential') || categoryLabel.includes('functional')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('statistic') && preferences.analytics) ||
                (categoryLabel.includes('performance') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising) ||
                (categoryLabel.includes('target') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(preferencesPanel, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit'
            ]) || preferencesPanel.querySelector('[fs-cc-button="submit"]') || 
               preferencesPanel.querySelector('[data-fs-cc-button="submit"]');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Finsweet', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Finsweet', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Finsweet - ${error.message}`);
    notifyBackgroundScript('Finsweet', false);
  }
}