/**
 * Ketch handler for Cookie Away
 */

function detectKetch() {
  try {
    // Look for Ketch specific elements
    return (
      document.querySelector('.ketch-modal') ||
      document.querySelector('[id^="ketch-"]') ||
      document.querySelector('[class^="ketch-"]') ||
      typeof window.Ketch !== 'undefined' ||
      typeof window.ketchConsent !== 'undefined' ||
      typeof window.ketchCmp !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Ketch - ${error.message}`);
    return false;
  }
}

function handleKetch(preferences) {
  try {
    // Get the Ketch modal
    const modal = document.querySelector('.ketch-modal') || 
                  document.querySelector('[id^="ketch-"][id*="-modal"]') ||
                  document.querySelector('[class^="ketch-"][class*="-modal"]');
    
    if (!modal) {
      console.log('Cookie Away: Ketch modal not found');
      notifyBackgroundScript('Ketch', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(modal, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || modal.querySelector('[data-ketch-action-type="ACCEPT_ALL"]');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(modal, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || modal.querySelector('[data-ketch-action-type="REJECT_ALL"]');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(modal, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'manage preferences', 'personalise choices'
      ]) || modal.querySelector('[data-ketch-action-type="CUSTOMIZE"]');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the preferences panel
          const preferencesPanel = document.querySelector('.ketch-modal__purposes') ||
                                document.querySelector('[class*="ketch-"][class*="purposes"]');
          
          if (preferencesPanel) {
            // Find the toggle switches
            const switches = preferencesPanel.querySelectorAll('input[type="checkbox"], [role="switch"], [role="checkbox"]');
            
            // Loop through switches and set preferences
            switches.forEach(toggle => {
              if (toggle.disabled) return;
              
              const purposeContainer = toggle.closest('[class*="purpose"]') || toggle.closest('[class*="category"]');
              if (!purposeContainer) return;
              
              const purposeLabel = purposeContainer.textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (purposeLabel.includes('necessary') || purposeLabel.includes('required') || 
                  purposeLabel.includes('essential') || purposeLabel.includes('legal')) {
                return;
              }
              
              // Determine the checked state - Ketch uses ARIA attributes in some cases
              const isChecked = toggle.hasAttribute('type') ? toggle.checked : toggle.getAttribute('aria-checked') === 'true';
              
              // Set toggle according to preferences
              if (
                (purposeLabel.includes('analytic') && preferences.analytics) ||
                (purposeLabel.includes('statistic') && preferences.analytics) ||
                (purposeLabel.includes('measure') && preferences.analytics) ||
                (purposeLabel.includes('functional') && preferences.functional) ||
                (purposeLabel.includes('preference') && preferences.functional) ||
                (purposeLabel.includes('personaliz') && preferences.functional) ||
                (purposeLabel.includes('customiz') && preferences.functional) ||
                (purposeLabel.includes('advertis') && preferences.advertising) ||
                (purposeLabel.includes('market') && preferences.advertising) ||
                (purposeLabel.includes('target') && preferences.advertising) ||
                (purposeLabel.includes('social') && preferences.advertising)
              ) {
                if (!isChecked) toggle.click();
              } else {
                if (isChecked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(preferencesPanel, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit',
              'save and close', 'save & close', 'confirm my choices'
            ]) || preferencesPanel.querySelector('[data-ketch-action-type="SAVE_PREFERENCES"]') ||
               modal.querySelector('button[data-testid="submitSelectedPreferencesButton"]');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Ketch', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Ketch', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Ketch - ${error.message}`);
    notifyBackgroundScript('Ketch', false);
  }
}