/**
 * Klaro! handler for Cookie Away
 */

function detectKlaro() {
  try {
    // Look for Klaro specific elements
    return (
      document.querySelector('.klaro') ||
      document.getElementById('klaro') ||
      document.querySelector('[class*="klaro"]') ||
      document.querySelector('[id^="klaro"]') ||
      typeof window.klaro !== 'undefined' ||
      typeof window.klaroConfig !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Klaro - ${error.message}`);
    return false;
  }
}

function handleKlaro(preferences) {
  try {
    // Get the Klaro notice
    const notice = document.querySelector('.klaro .cookie-notice') || 
                  document.querySelector('.klaro .context-notice');
    
    if (!notice) {
      console.log('Cookie Away: Klaro notice not found');
      notifyBackgroundScript('Klaro', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(notice, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || notice.querySelector('.cm-btn-accept-all');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(notice, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || notice.querySelector('.cm-btn-decline');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(notice, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'more options', 'choose'
      ]) || notice.querySelector('.cm-btn-manage');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the consent modal
          const consentModal = document.querySelector('.klaro .cookie-modal') ||
                             document.querySelector('.klaro .consent-modal');
          
          if (consentModal) {
            // Find the purpose items
            const purposeItems = consentModal.querySelectorAll('.cm-purpose');
            
            // Loop through purpose items and set preferences
            purposeItems.forEach(item => {
              const toggle = item.querySelector('input[type="checkbox"]');
              if (!toggle || toggle.disabled) return;
              
              const purposeLabel = item.querySelector('.cm-purpose-title, h3').textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (purposeLabel.includes('necessary') || purposeLabel.includes('required') || 
                  purposeLabel.includes('essential') || purposeLabel.includes('functional')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (purposeLabel.includes('analytic') && preferences.analytics) ||
                (purposeLabel.includes('statistic') && preferences.analytics) ||
                (purposeLabel.includes('performance') && preferences.analytics) ||
                (purposeLabel.includes('functional') && preferences.functional) ||
                (purposeLabel.includes('preference') && preferences.functional) ||
                (purposeLabel.includes('personal') && preferences.functional) ||
                (purposeLabel.includes('advertis') && preferences.advertising) ||
                (purposeLabel.includes('market') && preferences.advertising) ||
                (purposeLabel.includes('target') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(consentModal, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit',
              'close', 'accept selection'
            ]) || consentModal.querySelector('.cm-btn-accept, .cm-btn-save');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Klaro', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Klaro', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Klaro - ${error.message}`);
    notifyBackgroundScript('Klaro', false);
  }
}