/**
 * Osano handler for Cookie Away
 */

function detectOsano() {
  try {
    // Look for Osano specific elements
    return (
      document.querySelector('.osano-cm-widget') ||
      document.querySelector('.osano-cm-dialog') ||
      document.querySelector('.osano-cm-button') ||
      document.querySelector('[id^="osano-"]') ||
      document.querySelector('div[aria-describedby="osano-cm-description"]') ||
      typeof window.Osano !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Osano - ${error.message}`);
    return false;
  }
}

function handleOsano(preferences) {
  try {
    // Get the Osano banner or dialog
    const banner = document.querySelector('.osano-cm-widget') || 
                  document.querySelector('.osano-cm-dialog') ||
                  document.querySelector('div[aria-describedby="osano-cm-description"]');
    
    if (!banner) {
      console.log('Cookie Away: Osano banner not found');
      notifyBackgroundScript('Osano', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(banner, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || banner.querySelector('.osano-cm-accept');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(banner, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || banner.querySelector('.osano-cm-deny');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(banner, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings'
      ]) || banner.querySelector('.osano-cm-customize');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the settings dialog
          const settingsDialog = document.querySelector('.osano-cm-dialog--type_settings');
          
          if (settingsDialog) {
            // Find the category toggles
            const categoryGroups = settingsDialog.querySelectorAll('.osano-cm-toggle');
            
            // Loop through toggles and set preferences
            categoryGroups.forEach(group => {
              const toggle = group.querySelector('input[type="checkbox"]');
              if (!toggle) return;
              
              const categoryLabel = group.textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || categoryLabel.includes('essential') || toggle.disabled) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('performance') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising) ||
                (categoryLabel.includes('target') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(settingsDialog, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit'
            ]) || settingsDialog.querySelector('.osano-cm-save');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Osano', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Osano', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Osano - ${error.message}`);
    notifyBackgroundScript('Osano', false);
  }
}