/**
 * Piwik PRO CMP handler for Cookie Away
 */

function detectPiwikPro() {
  try {
    // Look for Piwik PRO specific elements
    return (
      document.querySelector('.ppms_cm_popup_overlay') ||
      document.querySelector('[id^="ppms_cm_"]') ||
      document.querySelector('[class^="ppms_cm_"]') ||
      typeof window.ppms !== 'undefined' ||
      typeof window.ppms_cm !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Piwik PRO - ${error.message}`);
    return false;
  }
}

function handlePiwikPro(preferences) {
  try {
    // Get the Piwik PRO popup
    const popup = document.querySelector('.ppms_cm_popup_overlay') || 
                 document.querySelector('[id^="ppms_cm_consent_popup"]');
    
    if (!popup) {
      console.log('Cookie Away: Piwik PRO popup not found');
      notifyBackgroundScript('Piwik PRO', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(popup, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || popup.querySelector('.ppms_cm_accept_all_button');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(popup, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || popup.querySelector('.ppms_cm_reject_all_button');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(popup, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'choose preferences', 'advanced settings'
      ]) || popup.querySelector('.ppms_cm_settings_button');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the settings view
          const settingsView = document.querySelector('.ppms_cm_settings_popup') ||
                             document.querySelector('[id^="ppms_cm_settings"]');
          
          if (settingsView) {
            // Find the toggle switches
            const toggles = settingsView.querySelectorAll('.ppms_cm_purpose_switch input[type="checkbox"]');
            
            // Loop through toggles and set preferences
            toggles.forEach(toggle => {
              if (toggle.disabled) return;
              
              const purposeContainer = toggle.closest('.ppms_cm_purpose_container');
              if (!purposeContainer) return;
              
              const purposeLabel = purposeContainer.querySelector('.ppms_cm_purpose_name').textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (purposeLabel.includes('necessary') || purposeLabel.includes('required') || 
                  purposeLabel.includes('essential') || purposeLabel.includes('functional')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (purposeLabel.includes('analytic') && preferences.analytics) ||
                (purposeLabel.includes('statistic') && preferences.analytics) ||
                (purposeLabel.includes('measure') && preferences.analytics) ||
                (purposeLabel.includes('functional') && preferences.functional) ||
                (purposeLabel.includes('preference') && preferences.functional) ||
                (purposeLabel.includes('personal') && preferences.functional) ||
                (purposeLabel.includes('advertis') && preferences.advertising) ||
                (purposeLabel.includes('market') && preferences.advertising) ||
                (purposeLabel.includes('target') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(settingsView, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit'
            ]) || settingsView.querySelector('.ppms_cm_settings_save_button');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Piwik PRO', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Piwik PRO', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Piwik PRO - ${error.message}`);
    notifyBackgroundScript('Piwik PRO', false);
  }
}