/**
 * Quantcast Choice handler for Cookie Away
 */

function detectQuantcast() {
  try {
    // Look for Quantcast specific elements
    return (
      document.getElementById('qc-cmp2-container') ||
      document.querySelector('.qc-cmp2-container') ||
      document.querySelector('[id^="qc-cmp2-"]') ||
      document.querySelector('[class^="qc-cmp2-"]') ||
      typeof window.__cmp !== 'undefined' ||
      typeof window.__tcfapi !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Quantcast - ${error.message}`);
    return false;
  }
}

function handleQuantcast(preferences) {
  try {
    // Get the Quantcast dialog
    const dialog = document.getElementById('qc-cmp2-container') || 
                  document.querySelector('.qc-cmp2-container');
    
    if (!dialog) {
      console.log('Cookie Away: Quantcast dialog not found');
      notifyBackgroundScript('Quantcast', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(dialog, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || dialog.querySelector('[title="Accept"]') || dialog.querySelector('[mode="primary"]');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(dialog, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || dialog.querySelector('[title="Reject"]') || dialog.querySelector('[mode="secondary"]');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(dialog, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'more options', 'manage consent'
      ]) || dialog.querySelector('[title="More Options"]');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Quantcast's UI structure involves multiple panel layers
          const purposePanel = document.querySelector('.qc-cmp2-summary-section');
          
          if (purposePanel) {
            // Find the category toggles - Quantcast has a more complex structure with accordion panels
            const toggles = purposePanel.querySelectorAll('input[type="checkbox"]');
            
            // Loop through toggles and set preferences
            toggles.forEach(toggle => {
              if (toggle.disabled) return;
              
              const categoryLabel = toggle.closest('.qc-cmp2-summary-info, [class*="purpose-item"]').textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || categoryLabel.includes('essential') || 
                  categoryLabel.includes('legitimate') || categoryLabel.includes('legal')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('measure') && preferences.analytics) ||
                (categoryLabel.includes('performance') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('feature') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising) ||
                (categoryLabel.includes('target') && preferences.advertising) ||
                (categoryLabel.includes('content') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(dialog, [
              'save', 'confirm', 'apply', 'update', 'save & exit', 'continue', 'done'
            ]) || dialog.querySelector('.qc-cmp2-footer button:last-child');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Quantcast', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Quantcast', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Quantcast - ${error.message}`);
    notifyBackgroundScript('Quantcast', false);
  }
}