/**
 * Sourcepoint handler for Cookie Away
 */

function detectSourcepoint() {
  try {
    // Look for Sourcepoint specific elements
    return (
      document.getElementById('sp_message_container') ||
      document.querySelector('.sp_message_container') ||
      document.querySelector('.sp_choice_type_11') ||
      document.querySelector('[class^="sp_"]') ||
      document.querySelector('[id^="sp_"]') ||
      typeof window._sp_ !== 'undefined' ||
      typeof window._sp_queue !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Sourcepoint - ${error.message}`);
    return false;
  }
}

function handleSourcepoint(preferences) {
  try {
    // Get the Sourcepoint message container
    const container = document.getElementById('sp_message_container') || 
                     document.querySelector('.sp_message_container');
    
    if (!container) {
      console.log('Cookie Away: Sourcepoint container not found');
      notifyBackgroundScript('Sourcepoint', false);
      return;
    }
    
    const dialog = container.querySelector('.message-component') || container.firstElementChild;
    
    if (!dialog) {
      console.log('Cookie Away: Sourcepoint dialog not found');
      notifyBackgroundScript('Sourcepoint', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(dialog, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept', 'agree'
      ]) || dialog.querySelector('.sp_choice_type_11') || dialog.querySelector('[title="ACCEPT ALL"]');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(dialog, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || dialog.querySelector('.sp_choice_type_12') || dialog.querySelector('[title="REJECT ALL"]');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(dialog, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'manage preferences', 'manage my choices', 'more options'
      ]) || dialog.querySelector('.sp_choice_type_13') || dialog.querySelector('[title="MANAGE OPTIONS"]');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Find the Sourcepoint purpose list
          const purposeList = document.querySelector('.sp_choice_type_SAVE_AND_EXIT')
            ? document.querySelector('.purposes-container')
            : document.querySelector('.sp-message-component') || container.querySelector('.message-component');
          
          if (purposeList) {
            // Find the toggle switches
            const toggles = purposeList.querySelectorAll('input[type="checkbox"], [role="switch"], [role="checkbox"]');
            
            // Loop through toggles and set preferences
            toggles.forEach(toggle => {
              if (toggle.disabled) return;
              
              // Get the purpose label from the nearby text
              const purposeItem = toggle.closest('div[class*="purpose"], div[class*="Purpose"], li');
              if (!purposeItem) return;
              
              const purposeLabel = purposeItem.textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (purposeLabel.includes('necessary') || purposeLabel.includes('required') || 
                  purposeLabel.includes('essential') || purposeLabel.includes('legitimate')) {
                return;
              }
              
              // Determine the current checked state
              const isChecked = toggle.type === 'checkbox' 
                ? toggle.checked 
                : toggle.getAttribute('aria-checked') === 'true';
              
              // Set toggle according to preferences
              if (
                (purposeLabel.includes('analytic') && preferences.analytics) ||
                (purposeLabel.includes('statistic') && preferences.analytics) ||
                (purposeLabel.includes('research') && preferences.analytics) ||
                (purposeLabel.includes('measure') && preferences.analytics) ||
                (purposeLabel.includes('functional') && preferences.functional) ||
                (purposeLabel.includes('preference') && preferences.functional) ||
                (purposeLabel.includes('personal') && preferences.functional) ||
                (purposeLabel.includes('advertis') && preferences.advertising) ||
                (purposeLabel.includes('market') && preferences.advertising) ||
                (purposeLabel.includes('target') && preferences.advertising) ||
                (purposeLabel.includes('social') && preferences.advertising)
              ) {
                if (!isChecked) toggle.click();
              } else {
                if (isChecked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(container, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit',
              'save and exit', 'save & exit'
            ]) || container.querySelector('.sp_choice_type_SAVE_AND_EXIT') || 
               container.querySelector('[title="SAVE & EXIT"]');
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Sourcepoint', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Sourcepoint', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Sourcepoint - ${error.message}`);
    notifyBackgroundScript('Sourcepoint', false);
  }
}