/**
 * Tarteaucitron.js handler for Cookie Away
 */

function detectTarteaucitron() {
  try {
    // Look for Tarteaucitron specific elements
    return (
      document.getElementById('tarteaucitronRoot') ||
      document.getElementById('tarteaucitronAlertBig') ||
      document.querySelector('[id^="tarteaucitron"]') ||
      document.querySelector('[class^="tarteaucitron"]') ||
      typeof window.tarteaucitron !== 'undefined' ||
      typeof window.tarteaucitronForceCDN !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Tarteaucitron - ${error.message}`);
    return false;
  }
}

function handleTarteaucitron(preferences) {
  try {
    // Get the Tarteaucitron alert
    const alert = document.getElementById('tarteaucitronAlertBig') || 
                 document.querySelector('.tarteaucitronAlertBig');
    
    if (!alert) {
      console.log('Cookie Away: Tarteaucitron alert not found');
      notifyBackgroundScript('Tarteaucitron', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(alert, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]) || document.getElementById('tarteaucitronAllAllowed') || 
          document.getElementById('tarteaucitronPersonalize') ||
          document.getElementById('tarteaucitronPersonalize2');
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(alert, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]) || document.getElementById('tarteaucitronAllDenied') ||
          document.getElementById('tarteaucitronAllDenied2');
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(alert, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'personalize', 'more info'
      ]) || document.getElementById('tarteaucitronPersonalize') ||
          document.getElementById('tarteaucitronCloseAlert');
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for services list to appear
        setTimeout(() => {
          // Try to find the services panel
          const servicesPanel = document.getElementById('tarteaucitronServices') ||
                               document.querySelector('#tarteaucitronServicesTitle_mandatory').parentNode;
          
          if (servicesPanel) {
            // Find all service categories except mandatory
            const serviceCategories = Array.from(servicesPanel.children).filter(el => 
              el.id && el.id.startsWith('tarteaucitronServicesTitle_') && !el.id.includes('mandatory')
            );
            
            // Loop through service categories and set preferences
            serviceCategories.forEach(category => {
              const categoryId = category.id.replace('Title_', '');
              const categoryLabel = category.textContent.toLowerCase();
              const categoryContainer = document.getElementById(`tarteaucitronServices_${categoryId}`);
              
              if (!categoryContainer) return;
              
              // Find the toggle button for this category
              const allowButton = document.getElementById(`tarteaucitron${categoryId}AllAllowed`);
              const denyButton = document.getElementById(`tarteaucitron${categoryId}AllDenied`);
              
              if (!allowButton || !denyButton) return;
              
              // Set preference according to category
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('statistic') && preferences.analytics) ||
                (categoryLabel.includes('measure') && preferences.analytics) ||
                (categoryLabel.includes('audience') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('personal') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising) ||
                (categoryLabel.includes('target') && preferences.advertising) ||
                (categoryLabel.includes('pub') && preferences.advertising)
              ) {
                safeClick(allowButton);
              } else {
                safeClick(denyButton);
              }
            });
            
            // Find and click the close button to save settings
            const closeButton = document.getElementById('tarteaucitronClosePanel');
            
            if (closeButton) {
              safeClick(closeButton);
              notifyBackgroundScript('Tarteaucitron', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Tarteaucitron', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Tarteaucitron - ${error.message}`);
    notifyBackgroundScript('Tarteaucitron', false);
  }
}