/**
 * Termly handler for Cookie Away
 */

function detectTermly() {
  try {
    // Look for Termly specific elements
    return (
      document.getElementById('termly-code-snippet-banner') ||
      document.querySelector('.termly-styles-module') ||
      document.querySelector('[id^="termly"]') ||
      document.querySelector('[class*="termly"]') ||
      typeof window.Termly !== 'undefined' ||
      typeof window.termly !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting Termly - ${error.message}`);
    return false;
  }
}

function handleTermly(preferences) {
  try {
    // Get the Termly banner
    const banner = document.getElementById('termly-code-snippet-banner') || 
                  document.querySelector('.termly-styles-module') ||
                  document.querySelector('[id^="termly-consent"]');
    
    if (!banner) {
      console.log('Cookie Away: Termly banner not found');
      notifyBackgroundScript('Termly', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(banner, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'I accept', 'accept'
      ]);
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(banner, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'reject'
      ]);
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(banner, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings',
        'preference center', 'manage consent'
      ]);
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the settings dialog
          const settingsDialog = document.querySelector('.termly-styles-preferences-center') ||
                               document.querySelector('[id^="termly-consent-preferences"]');
          
          if (settingsDialog) {
            // Find the category toggles
            const categoryRows = settingsDialog.querySelectorAll('[class*="-preference-item"]') || 
                               settingsDialog.querySelectorAll('[id*="-preference-item"]');
            
            // Loop through rows and toggle preferences
            categoryRows.forEach(row => {
              const toggle = row.querySelector('input[type="checkbox"]');
              if (!toggle || toggle.disabled) return;
              
              const categoryLabel = row.textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be toggled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || categoryLabel.includes('essential')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('performance') && preferences.analytics) ||
                (categoryLabel.includes('statistic') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising) ||
                (categoryLabel.includes('target') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(settingsDialog, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit'
            ]);
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('Termly', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('Termly', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling Termly - ${error.message}`);
    notifyBackgroundScript('Termly', false);
  }
}