/**
 * TrustArc handler for Cookie Away
 */

function detectTrustArc() {
  try {
    // Look for TrustArc specific elements
    return (
      document.getElementById('truste-consent-track') ||
      document.getElementById('truste-consent-content') ||
      document.getElementById('truste-consent-required') ||
      document.querySelector('.truste_box_overlay') ||
      document.querySelector('.truste_overlay') ||
      document.querySelector('[id^="truste-consent"]') ||
      typeof window.truste !== 'undefined' ||
      typeof window.__trcpl !== 'undefined'
    );
  } catch (error) {
    console.log(`Cookie Away: Error detecting TrustArc - ${error.message}`);
    return false;
  }
}

function handleTrustArc(preferences) {
  try {
    // Get the TrustArc banner
    const banner = document.getElementById('truste-consent-track') || 
                  document.querySelector('.truste_box_overlay') ||
                  document.querySelector('.truste_overlay');
    
    if (!banner) {
      console.log('Cookie Away: TrustArc banner not found');
      notifyBackgroundScript('TrustArc', false);
      return;
    }
    
    // Find the appropriate buttons based on preferences
    let buttonToClick;
    
    // Accept all cookies
    if (preferences.acceptAll) {
      buttonToClick = findButtonByText(banner, [
        'accept all', 'allow all', 'agree to all', 'accept cookies', 
        'allow cookies', 'consent to all', 'i accept', 'accept'
      ]);
    }
    // Reject non-essential cookies
    else if (preferences.rejectAll) {
      buttonToClick = findButtonByText(banner, [
        'reject all', 'decline all', 'necessary only', 'reject non-essential',
        'reject cookies', 'deny', 'decline cookies', 'decline', 'reject'
      ]);
    }
    // Apply specific preferences
    else {
      // First try to find a customize/settings button
      const customizeButton = findButtonByText(banner, [
        'customize', 'settings', 'preferences', 'configure', 'manage', 'cookie settings', 'more info'
      ]);
      
      if (customizeButton) {
        safeClick(customizeButton);
        
        // Wait a moment for settings panel to appear
        setTimeout(() => {
          // Try to find the preference UI
          const settingsPanel = document.querySelector('.truste_box_overlay_inner') ||
                              document.querySelector('.truste-preference-center');
          
          if (settingsPanel) {
            // Find the category toggles
            const categoryToggles = settingsPanel.querySelectorAll('input[type="checkbox"]');
            
            // Loop through toggles and set preferences
            categoryToggles.forEach(toggle => {
              const categoryLabel = toggle.closest('div').textContent.toLowerCase();
              
              // Skip if necessary/required cookies (usually can't be disabled)
              if (categoryLabel.includes('necessary') || categoryLabel.includes('required') || categoryLabel.includes('essential')) {
                return;
              }
              
              // Set toggle according to preferences
              if (
                (categoryLabel.includes('analytic') && preferences.analytics) ||
                (categoryLabel.includes('functional') && preferences.functional) ||
                (categoryLabel.includes('preference') && preferences.functional) ||
                (categoryLabel.includes('advertis') && preferences.advertising) ||
                (categoryLabel.includes('market') && preferences.advertising) ||
                (categoryLabel.includes('target') && preferences.advertising)
              ) {
                if (!toggle.checked) toggle.click();
              } else {
                if (toggle.checked) toggle.click();
              }
            });
            
            // Find and click the save/confirm button
            const saveButton = findButtonByText(settingsPanel, [
              'save', 'confirm', 'apply', 'update', 'save preferences', 'save settings', 'submit', 'confirm my choices'
            ]);
            
            if (saveButton) {
              safeClick(saveButton);
              notifyBackgroundScript('TrustArc', true);
            }
          }
        }, 500);
      }
    }
    
    if (buttonToClick) {
      safeClick(buttonToClick);
      notifyBackgroundScript('TrustArc', true);
    }
  } catch (error) {
    console.log(`Cookie Away: Error handling TrustArc - ${error.message}`);
    notifyBackgroundScript('TrustArc', false);
  }
}